@@ -2,11 +2,8 @@ package MooseX::Getopt::Basic;
 BEGIN {
   $MooseX::Getopt::Basic::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::Basic::VERSION = '0.58';
-}
 # ABSTRACT: MooseX::Getopt::Basic - role to implement the Getopt::Long functionality
-
+$MooseX::Getopt::Basic::VERSION = '0.60';
 use Moose::Role;
 
 use MooseX::Getopt::OptionTypeMap;
@@ -17,6 +14,7 @@ use Try::Tiny;
 use Carp ();
 
 use Getopt::Long 2.37 ();
+use namespace::autoclean;
 
 has ARGV       => (is => 'rw', isa => 'ArrayRef', traits => ['NoGetopt']);
 has extra_argv => (is => 'rw', isa => 'ArrayRef', traits => ['NoGetopt']);
@@ -176,6 +174,9 @@ sub _getopt_full_usage
     exit 0;
 }
 #(this is already documented in MooseX::Getopt. But FIXME later, via RT#82195)
+# =for Pod::Coverage
+#     print_usage_text
+# =cut
 sub print_usage_text { shift->_getopt_full_usage(@_) }
 
 sub _usage_format {
@@ -268,21 +269,15 @@ sub _attrs_to_options {
     return @options;
 }
 
-no Moose::Role;
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc Brandon Devin Austin Drew Taylor
-Florian Ragwitz Gordon Irving Hans Dieter L Pearcey Hinrik rn Sigursson
-Jesse Luehrs John Goulah Jonathan Swartz Black Justin Hunter Karen
-Etheridge Nelo Onyiah Ricardo SIGNES Ryan D Chris Johnson Shlomi Fish Todd
-Hepler Tomas Doran Yuval Prather Kogman t0m var Arnfjr Bjarmason Dagfinn
-Ilmari Mannsker Damien Krotkine
+=for :stopwords Stevan Little Infinity Interactive, Inc
 
 =head1 NAME
 
@@ -290,7 +285,7 @@ MooseX::Getopt::Basic - MooseX::Getopt::Basic - role to implement the Getopt::Lo
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -339,7 +334,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
