@@ -2,14 +2,11 @@ package MooseX::Getopt::Dashes;
 BEGIN {
   $MooseX::Getopt::Dashes::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::Dashes::VERSION = '0.58';
-}
 # ABSTRACT: convert underscores in attribute names to dashes
-
+$MooseX::Getopt::Dashes::VERSION = '0.60';
 use Moose::Role;
-
 with 'MooseX::Getopt';
+use namespace::autoclean;
 
 around _get_cmd_flags_for_attr => sub {
     my $next = shift;
@@ -23,22 +20,15 @@ around _get_cmd_flags_for_attr => sub {
     return ( $flag, @aliases );
 };
 
-no Moose::Role;
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc Brandon Devin Austin Drew Taylor
-Florian Ragwitz Gordon Irving Hans Dieter L Pearcey Hinrik rn Sigursson
-Jesse Luehrs John Goulah Jonathan Swartz Black Justin Hunter Karen
-Etheridge Nelo Onyiah Ricardo SIGNES Ryan D Chris Johnson Shlomi Fish Todd
-Hepler Tomas Doran Yuval Prather Kogman t0m var Arnfjr Bjarmason Dagfinn
-Ilmari Mannsker Damien Krotkine
+=for :stopwords Stevan Little Infinity Interactive, Inc
 
 =head1 NAME
 
@@ -46,7 +36,7 @@ MooseX::Getopt::Dashes - convert underscores in attribute names to dashes
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -88,7 +78,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
