@@ -2,18 +2,14 @@ package MooseX::Getopt::GLD;
 BEGIN {
   $MooseX::Getopt::GLD::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::GLD::VERSION = '0.58';
-}
 # ABSTRACT: A Moose role for processing command line options with Getopt::Long::Descriptive
-
+$MooseX::Getopt::GLD::VERSION = '0.60';
 use strict;
 use warnings;
 use MooseX::Role::Parameterized;
-
 use Getopt::Long::Descriptive 0.081;
-
 with 'MooseX::Getopt::Basic';
+use namespace::autoclean;
 
 parameter getopt_conf => (
     isa => 'ArrayRef[Str]',
@@ -94,7 +90,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Stevan Little Infinity Interactive, Inc
 
@@ -104,7 +100,7 @@ MooseX::Getopt::GLD - A Moose role for processing command line options with Geto
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -147,7 +143,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
