@@ -2,17 +2,14 @@ package MooseX::Getopt::Meta::Attribute::NoGetopt;
 BEGIN {
   $MooseX::Getopt::Meta::Attribute::NoGetopt::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::Meta::Attribute::NoGetopt::VERSION = '0.58';
-}
-# ABSTRACT: Optional meta attribute for ignoring params
-
+# ABSTRACT: Optional meta attribute for ignoring parameters
+$MooseX::Getopt::Meta::Attribute::NoGetopt::VERSION = '0.60';
 use Moose;
 
 extends 'Moose::Meta::Attribute'; # << Moose extending Moose :)
    with 'MooseX::Getopt::Meta::Attribute::Trait::NoGetopt';
 
-no Moose;
+use namespace::autoclean;
 
 # register this as a metaclass alias ...
 package # stop confusing PAUSE
@@ -25,17 +22,17 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Stevan Little Infinity Interactive, Inc
 
 =head1 NAME
 
-MooseX::Getopt::Meta::Attribute::NoGetopt - Optional meta attribute for ignoring params
+MooseX::Getopt::Meta::Attribute::NoGetopt - Optional meta attribute for ignoring parameters
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -85,7 +82,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
