@@ -2,13 +2,13 @@ package MooseX::Getopt::OptionTypeMap;
 BEGIN {
   $MooseX::Getopt::OptionTypeMap::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::OptionTypeMap::VERSION = '0.58';
-}
 # ABSTRACT: Storage for the option to type mappings
-
-use Moose 'confess', 'blessed';
+$MooseX::Getopt::OptionTypeMap::VERSION = '0.60';
+use Moose;
+use Carp 'confess';
+use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints 'find_type_constraint';
+use namespace::autoclean;
 
 my %option_type_map = (
     'Bool'     => '!',
@@ -91,16 +91,13 @@ sub add_option_type_to_map {
     $option_type_map{$type_name} = $option_string;
 }
 
-no Moose::Util::TypeConstraints;
-no Moose;
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Stevan Little Infinity Interactive, Inc
 
@@ -110,7 +107,7 @@ MooseX::Getopt::OptionTypeMap - Storage for the option to type mappings
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 DESCRIPTION
 
@@ -131,7 +128,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
