@@ -2,11 +2,10 @@ package MooseX::Getopt::ProcessedArgv;
 BEGIN {
   $MooseX::Getopt::ProcessedArgv::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::ProcessedArgv::VERSION = '0.58';
-}
-use Moose;
 # ABSTRACT: MooseX::Getopt::ProcessedArgv - Class containing the results of process_argv
+$MooseX::Getopt::ProcessedArgv::VERSION = '0.60';
+use Moose;
+use namespace::autoclean;
 
 has 'argv_copy'          => (is => 'ro', isa => 'ArrayRef');
 has 'extra_argv'         => (is => 'ro', isa => 'ArrayRef');
@@ -14,8 +13,6 @@ has 'usage'              => (is => 'ro', isa => 'Maybe[Object]');
 has 'constructor_params' => (is => 'ro', isa => 'HashRef');
 has 'cli_params'         => (is => 'ro', isa => 'HashRef');
 
-no Moose;
-
 __PACKAGE__->meta->make_immutable();
 
 1;
@@ -24,7 +21,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =for :stopwords Stevan Little Infinity Interactive, Inc
 
@@ -34,7 +31,7 @@ MooseX::Getopt::ProcessedArgv - MooseX::Getopt::ProcessedArgv - Class containing
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 SYNOPSIS
 
@@ -83,7 +80,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
