@@ -2,12 +2,10 @@ package MooseX::Getopt::Strict;
 BEGIN {
   $MooseX::Getopt::Strict::AUTHORITY = 'cpan:STEVAN';
 }
-{
-  $MooseX::Getopt::Strict::VERSION = '0.58';
-}
-# ABSTRACT: only make options for attrs with the Getopt metaclass
-
+# ABSTRACT: only make options for attributes with the Getopt metaclass
+$MooseX::Getopt::Strict::VERSION = '0.60';
 use Moose::Role;
+use namespace::autoclean;
 
 with 'MooseX::Getopt';
 
@@ -19,30 +17,23 @@ around '_compute_getopt_attrs' => sub {
     } $class->$next(@args);
 };
 
-no Moose::Role;
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
-=for :stopwords Stevan Little Infinity Interactive, Inc Brandon Devin Austin Drew Taylor
-Florian Ragwitz Gordon Irving Hans Dieter L Pearcey Hinrik rn Sigursson
-Jesse Luehrs John Goulah Jonathan Swartz Black Justin Hunter Karen
-Etheridge Nelo Onyiah Ricardo SIGNES Ryan D Chris Johnson Shlomi Fish Todd
-Hepler Tomas Doran Yuval Prather Kogman t0m var Arnfjr Bjarmason Dagfinn
-Ilmari Mannsker Damien Krotkine
+=for :stopwords Stevan Little Infinity Interactive, Inc
 
 =head1 NAME
 
-MooseX::Getopt::Strict - only make options for attrs with the Getopt metaclass
+MooseX::Getopt::Strict - only make options for attributes with the Getopt metaclass
 
 =head1 VERSION
 
-version 0.58
+version 0.60
 
 =head1 DESCRIPTION
 
@@ -56,7 +47,7 @@ Stevan Little <stevan@iinteractive.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Infinity Interactive, Inc.
+This software is copyright (c) 2007 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
